/*****************************************************************
* This program analyzes election data as reported in Table 6     *
* of Huber/Arceneaux 2007.                                       *
*                                                                *
* The .do file uses this dataset:                                *
* 1996to2000voteshiftbycounty_withmedia.dta;                     *
*                                                                *
* April 2007, Gregory Huber and Kevin Arceneaux                  *
*****************************************************************/

#delimit ;
clear;
set mem 250m;
set more off;

use 1996to2000voteshiftbycounty_withmedia.dta;

replace state=lower(state);

/*battle ground states per BGVEP*/
gen BGVEP=0;
replace BGVEP=1 if state=="ar";
replace BGVEP=1 if state=="de";
replace BGVEP=1 if state=="fl";
replace BGVEP=1 if state=="il";
replace BGVEP=1 if state=="ia";
replace BGVEP=1 if state=="ky";
replace BGVEP=1 if state=="la";
replace BGVEP=1 if state=="me";
replace BGVEP=1 if state=="mi";
replace BGVEP=1 if state=="mn";
replace BGVEP=1 if state=="mo";
replace BGVEP=1 if state=="mt";
replace BGVEP=1 if state=="nv";
replace BGVEP=1 if state=="nh";
replace BGVEP=1 if state=="nm";
replace BGVEP=1 if state=="oh";
replace BGVEP=1 if state=="or";
replace BGVEP=1 if state=="pa";
replace BGVEP=1 if state=="tn";
replace BGVEP=1 if state=="wa";
replace BGVEP=1 if state=="wi";
rename BGVEP battleground;

/*these are states with multiple media markets*/
gen multimarket=0;
replace multimarket=1 if state=="al";
replace multimarket=1 if state=="ar";
replace multimarket=1 if state=="az";
replace multimarket=1 if state=="ca";
replace multimarket=1 if state=="co";
replace multimarket=1 if state=="ct";
replace multimarket=1 if state=="fl";
replace multimarket=1 if state=="ga";
replace multimarket=1 if state=="ia";
replace multimarket=1 if state=="id";
replace multimarket=1 if state=="il";
replace multimarket=1 if state=="in";
replace multimarket=1 if state=="ks";
replace multimarket=1 if state=="ky";
replace multimarket=1 if state=="ma";
replace multimarket=1 if state=="md";
replace multimarket=1 if state=="mi";
replace multimarket=1 if state=="mo";
replace multimarket=1 if state=="ms";
replace multimarket=1 if state=="mt";
replace multimarket=1 if state=="nc";
replace multimarket=1 if state=="ne";
replace multimarket=1 if state=="nh";
replace multimarket=1 if state=="nj";
replace multimarket=1 if state=="nv";
replace multimarket=1 if state=="ny";
replace multimarket=1 if state=="oh";
replace multimarket=1 if state=="ok";
replace multimarket=1 if state=="or";
replace multimarket=1 if state=="pa";
replace multimarket=1 if state=="sc";
replace multimarket=1 if state=="tn";
replace multimarket=1 if state=="tx";
replace multimarket=1 if state=="va";
replace multimarket=1 if state=="vt";
replace multimarket=1 if state=="wa";
replace multimarket=1 if state=="wi";
replace multimarket=1 if state=="wv";
replace multimarket=1 if state=="wy";

gen mzone=state+string(mmn);
encode state, gen(stnum);

tab stnum if multimarket==1 & battleground==0, gen(nonbgsd_);
tab stnum if multimarket==1 & battleground==1, gen(bgsd_);
tab stnum if multimarket==1, gen(sd_);

gen republican_boost= rpct00-rpct96;

summ republican_boost, detail;

/******************
*  non-bg and bg states states **
******************/;

*These are the specifications reported in the paper;

reg republican_boost Sept1pro_bush_grp Sept1pro_gore_grp nonbgsd_* if multimarket==1 & battleground==0, cluster(mzone) robust;
outreg using Table6.out, nocons coefastr 3aster se addstat(`r2') bfmt(fc) bdec(4) tdec(2) replace;
reg republican_boost Oct1pro_bush_grp Oct1pro_gore_grp nonbgsd_* if multimarket==1 & battleground==0, cluster(mzone) robust;
outreg using Table6.out, nocons coefastr 3aster se addstat(`r2') bfmt(fc) bdec(4) tdec(2) append;

*These are additional specifications;

*examine effects in battleground states;
reg republican_boost Sept1pro_bush_grp Sept1pro_gore_grp bgsd_* if multimarket==1 & battleground==1, cluster(mzone) robust;
outreg using Table6inBGStates.out, nocons coefastr 3aster se addstat(`r2') bfmt(fc) bdec(4) tdec(2) replace;
reg republican_boost Oct1pro_bush_grp Oct1pro_gore_grp bgsd_* if multimarket==1 & battleground==1, cluster(mzone) robust;
outreg using Table6inBGStates.out, nocons coefastr 3aster se addstat(`r2') bfmt(fc) bdec(4) tdec(2) append;
