/*****************************************************************
* This program analyzes the bias in reported campaign contact    *
* as reported in Table A1C of Huber/Arceneaux 2007.              *
*                                                                *
* The .do file uses this dataset:                                *
* biasinreportedcontactanalysis.dta;                             *
*                                                                *
* April 2007, Gregory Huber and Kevin Arceneaux                  *
*****************************************************************/

#delimit;
set memory 64m;
set more off;
use biasinreportedcontactanalysis.dta;

*generate state indicators;
tab stnum, gen(sd_);

*no fixed effects, all states, indicator for battleground;
probit campaign_contact_during pre_dur_presadgrp battleground abspartisanship unionmem educ female black hispanic age age2, robust cluster(mmn);
outreg using "TableA1C.out", coefastr 3aster  se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle("(1)") nonotes replace;

predict ccd if e(sample);
replace ccd=1 if ccd>.5;
replace ccd=0 if ccd<=.5;
count if e(sample);
count if e(sample) & ccd==campaign_contact_during;
drop ccd;

*fixed effects, all states;
probit campaign_contact_during pre_dur_presadgrp abspartisanship unionmem educ female black hispanic age age2 sd_*, robust cluster(mmn);
outreg using "TableA1C.out", coefastr 3aster  se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle("(1)") nonotes append;

predict ccd if e(sample);
replace ccd=1 if ccd>.5;
replace ccd=0 if ccd<=.5;
count if e(sample);
count if e(sample) & ccd==campaign_contact_during;
drop ccd;

*fixed effects, just non-battleground states;
probit campaign_contact_during pre_dur_presadgrp abspartisanship unionmem educ female black hispanic age age2 sd_* if battleground==0, robust cluster(mmn);
outreg using "TableA1C.out", coefastr 3aster  se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle("(1)") nonotes append;

predict ccd if e(sample);
replace ccd=1 if ccd>.5;
replace ccd=0 if ccd<=.5;
count if e(sample);
count if e(sample) & ccd==campaign_contact_during;
drop ccd;
