/*****************************************************************
* This program appends the advertising broadcast data to the     *
* the aggregated NAES datafiles for the analysis in              *
* Huber/Arceneaux 2007.                                          *
* The aggregated NAES cross section and panel datasets recoded   *
* by this do file should be in the subdirectory DataFiles        *
* The processed datafiles created by this do file are saved in   *
* the subdirectory DataFiles                                     *
*                                                                *
* April 2007, Gregory Huber and Kevin Arceneaux                  *
*****************************************************************/

#delimit ;
clear;
set mem 250m;
set more off;

********************************************
*Append Media Data to Cross Sectional File *
********************************************;

use DataFiles\CS.dta;

gen media_market=cw25;
sort media_market;

joinby media_market using DataFiles\media_market_number_to_mmn.dta;

gen year=int(cdate/10000);
gen month=int(cdate/100)-year*100;
gen day=int(cdate)-month*100-year*10000;
gen spotdate=mdy(month,day,year) ;
format spotdate %d;

/********************************************
* Merge in last 4 weeks of advertising data *
********************************************/;

gen seconddate=spotdate;
gen firstdate=seconddate-28;
sort mmn firstdate seconddate;
joinby mmn firstdate seconddate using DataFiles\ad_data_by_mmn_between_spotdates.dta;

*since these are actually 4 weeks of ads, we need to rename the variables;
rename presadgrp ms4_presadgrp;
rename pro_bush_grp ms4_pro_bush_grp;
rename pro_gore_grp ms4_pro_gore_grp;
rename totaladgrp ms4_totaladgrp;

drop firstdate seconddate spotdate;

compress;

save DataFiles\CS_mmn.dta, replace;
clear;

********************************************
*Append Media Data to Panel File           *
********************************************;

use DataFiles\Panel.dta;

gen media_market=cw25;
sort media_market;

joinby media_market using DataFiles\media_market_number_to_mmn.dta;

gen year=int(cdate/10000);
gen month=int(cdate/100)-year*100;
gen day=int(cdate)-month*100-year*10000;
gen firstdate=mdy(month,day,year) ;
format firstdate %d;

gen ryear=int(rdate/10000);
gen rmonth=int(rdate/100)-ryear*100;
gen rday=int(rdate)-rmonth*100-ryear*10000;
gen seconddate_hold=mdy(rmonth,rday,ryear) ;
format seconddate_hold %d;

*if second date is after nov7, we want to use media data through nov. 7;
*. disp mdy(11,07,2000);
*14921;
gen seconddate=seconddate_hold;
replace seconddate=14921 if seconddate>14921;

sort mmn firstdate seconddate;
joinby mmn firstdate seconddate using DataFiles\ad_data_by_mmn_between_spotdates.dta;

drop seconddate;
rename seconddate_hold seconddate;

compress;

save DataFiles\Panel_mmn.dta, replace;
