/*****************************************************************
* This program recodes the aggregated NAES datafiles for the     *
* analysis in Huber/Arceneaux 2007.                              *
* The aggregated NAES cross section and panel datasets recoded   *
* by this do file should be in the subdirectory DataFiles        *
* The processed datafiles created by this do file are saved in   *
* the subdirectory DataFiles                                     *
*                                                                *
* April 2007, Gregory Huber and Kevin Arceneaux                  *
*****************************************************************/

clear
set mem 100m
set more off

****************************************
* Recode Panels                        *
****************************************

use DataFiles\panel_mmn.dta, clear

/*

----------------------------------------------------------------------------------------------------------------
cdate                                                                    date of interview (local to respondent)
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (long)

                 range:  [19991214,20001106]          units:  1
         unique values:  322                      missing .:  0/51356

                  mean:   2.0e+07
              std. dev:   1267.07

           percentiles:        10%       25%       50%       75%       90%
                           2.0e+07   2.0e+07   2.0e+07   2.0e+07   2.0e+07

----------------------------------------------------------------------------------------------------------------
cst                                                                                                        state
----------------------------------------------------------------------------------------------------------------

                  type:  string (str2)

         unique values:  49                       missing "":  0/51356

              examples:  "FL"
                         "MD"
                         "NM"
                         "SC"

*/

gen interview_date=cdate
gen state=cst

/*
----------------------------------------------------------------------------------------------------------------
ca09                                                                                bush conservative or liberal
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca09

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  12256/51356

            tabulation:  Freq.   Numeric  Label
                          3730         1  very conservative
                         19137         2  conservative
                          9497         3  moderate
                          3077         4  liberal
                           851         5  very liberal
                          2666       998  dont know
                           142       999  no answer
                         12256         .  

----------------------------------------------------------------------------------------------------------------
ca19                                                                                gore conservative or liberal
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca19

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  12237/51356

            tabulation:  Freq.   Numeric  Label
                          1223         1  very conservative
                          5952         2  conservative
                         12261         3  moderate
                         12077         4  liberal
                          4792         5  very liberal
                          2663       998  dont know
                           151       999  no answer
                         12237         .  
*/

gen bush_ideology=(ca09-1)/4
replace bush_ideology=. if ca09>5

gen gore_ideology=(ca19-1)/4
replace gore_ideology=. if ca19>5

/*

--------------------------------------------------------------------------------------------------------------------------------------------
ca01                                                                                                                      favorability: bush
--------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca01, but 101 nonmissing values are not labeled

                 range:  [0,999]                      units:  1
         unique values:  104                      missing .:  0/51356

              examples:  30    
                         50    
                         75    
                         90    

--------------------------------------------------------------------------------------------------------------------------------------------
ca02                                                                                                                             cares: bush
--------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca02

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          4860         1  extremely well
                         16878         2  quite well
                         12798         3  not too well
                          7875         4  not well
                          2327       998  dont know
                           199       999  no answer
                          6419         .  

------------------------------------------------------------------------------------------------------------------------------------------
ca03                                                                                                                          honest: bush
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca03

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          6455         1  extremely well
                         20186         2  quite well
                         10493         3  not too well
                          4983         4  not well
                          2598       998  dont know
                           222       999  no answer
                          6419         .  

------------------------------------------------------------------------------------------------------------------------------------------
ca04                                                                                                                       inspiring: bush
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca04

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          4633         1  extremely well
                         16477         2  quite well
                         13838         3  not too well
                          7986         4  not well
                          1839       998  dont know
                           164       999  no answer
                          6419         .  

------------------------------------------------------------------------------------------------------------------------------------------
ca05                                                                                                                   knowledgeable: bush
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca05

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          6377         1  extremely well
                         23223         2  quite well
                          9317         3  not too well
                          4246         4  not well
                          1623       998  dont know
                           151       999  no answer
                          6419         .  

*/

gen bush_favorability=ca01
replace bush_favorability=. if bush_favorability>100

gen gore_favorability=ca11
replace gore_favorability=. if gore_favorability>100

gen bush_like1=ca02
recode bush_like1 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_like2=ca03
recode bush_like2 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_like3=ca04
recode bush_like3 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_like4=ca05
recode bush_like4 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_likes=bush_like1+bush_like2+bush_like3+bush_like4

gen gore_like1=ca12
recode gore_like1 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_like2=ca13
recode gore_like2 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_like3=ca14
recode gore_like3 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_like4=ca15
recode gore_like4 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_likes=gore_like1+gore_like2+gore_like3+gore_like4

/*

------------------------------------------------------------------------------------------------------------------------------------------
ck03                                                                                                   interested in presidential campaign
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ck03

                 range:  [1,999]                      units:  1
         unique values:  5                        missing .:  30634/51356

            tabulation:  Freq.   Numeric  Label
                          5604         1  very interested
                          8900         2  somewhat interested
                          6115         3  not much interested
                            79       998  dont know
                            24       999  no answer
                         30634         .  


*/

gen campaign_interest=ck03
recode campaign_interest 1=2 2=1 3=0 *=.
replace campaign_interest=campaign_interest/2

/*
----------------------------------------------------------------------------------------------------------------
cr30                                                                          intend to vote in general election
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cr30

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  10058/51356

            tabulation:  Freq.   Numeric  Label
                         35162         1  yes
                          4685         2  no
                          1406       998  dont know
                            45       999  no answer
                         10058         .  

*/

gen voteint=cr30
recode voteint 2=0 3/max=.

/*

----------------------------------------------------------------------------------------------------------------
cv01                                                                                                    party id
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv01

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         14243         1  republican
                         15874         2  democrat
                         14818         3  independent
                          4410         4  verbatim
                          1672       998  dont know
                           339       999  no answer

----------------------------------------------------------------------------------------------------------------
cv02                                                                                             party id strong
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv02

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  6421/51356

            tabulation:  Freq.   Numeric  Label
                         23598         1  strong
                         20394         2  not very strong
                           805       998  dont know
                           138       999  no answer
                          6421         .  

----------------------------------------------------------------------------------------------------------------
cv03                                                                               lean republican or democratic
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv03

                 range:  [1,999]                      units:  1
         unique values:  5                        missing .:  30117/51356

            tabulation:  Freq.   Numeric  Label
                          6665         1  republican
                          7427         2  democratic
                          5553         3  neither
                          1327       998  dont know
                           267       999  no answer
                         30117         .  

*/

gen pid5=.
replace pid5=2 if cv01==1 & cv02==1
replace pid5=1 if cv01==1 & cv02~=1
replace pid5=1 if (cv01==3 | cv01==4 | cv01==998) & cv03==1
replace pid5=0 if (cv01==3 | cv01==4 | cv01==998) & (cv03==3 | cv03==998)
replace pid5=-1 if (cv01==3 | cv01==4 | cv01==998) & cv03==2
replace pid5=-1 if cv01==2 & cv02~=1
replace pid5=-2 if cv01==2 & cv02==1
label var pid5 "Party ID (Scale, +2 Strong R to -2 Strong D)"

/*

----------------------------------------------------------------------------------------------------------------
cv04                                                                                     conservative or liberal
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv04

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          3263         1  very conservative
                         14865         2  conservative
                         20061         3  moderate
                          9388         4  liberal
                          1996         5  very liberal
                          1535       998  dont know
                           248       999  no answer

*/

gen ideology=cv04
recode ideology 1=2 2=1 3=0 4=-1 5=-2 *=0
label var ideology "Ideology (Scale, +2 Very Consv., -2 Very Lib.)"

/*

----------------------------------------------------------------------------------------------------------------
cw01                                                                                                         sex
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (byte)
                 label:  cw01

                 range:  [1,2]                        units:  1
         unique values:  2                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         22955         1  male
                         28401         2  female

----------------------------------------------------------------------------------------------------------------
cw02                                                                                                         age
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw02, but 80 nonmissing values are not labeled

                 range:  [18,999]                     units:  1
         unique values:  82                       missing .:  0/51356

              examples:  30    
                         40    
                         49    
                         61    

*/

gen female=cw01-1
label var female "Female (1=yes)"
gen age=cw02
recode age 900/max=.
label var age "Age (years)"

/*

----------------------------------------------------------------------------------------------------------------
cw03                                                                                                        race
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw03

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         42173         1  white
                          4511         2  black
                           853         3  asian
                          3052         4  verbatim
                           247       998  dont know
                           520       999  no answer

----------------------------------------------------------------------------------------------------------------
cw04                                                                               of hispanic or spanish origin
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw04

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          4048         1  yes
                         46960         2  no
                           100       998  dont know
                           248       999  no answer

----------------------------------------------------------------------------------------------------------------
cw05                                                                                  hispanic or spanish origin
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw05

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  47308/51356

            tabulation:  Freq.   Numeric  Label
                          2096         1  mexican
                           147         2  cuban
                           474         3  puerto rican
                          1250         4  verbatim
                            54       998  dont know
                            27       999  no answer
                         47308         .  
*/

gen white=cw03
recode white 1=1 2/4=0 *=.
label var white "White (1=yes)"

gen hispanic=0
replace hispanic=1 if cw04==1
replace hispanic=. if cw04>997
label var hispanic "Hispanic (1=yes)"

/*

----------------------------------------------------------------------------------------------------------------
cw06                                                                                                   education
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw06

                 range:  [1,999]                      units:  1
         unique values:  11                       missing .:  0/51356


                              education |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                   grade eight or lower |      1,455        2.83        2.83
           some high school, no diploma |      3,273        6.37        9.21
      high school diploma or equivalent |     14,597       28.42       37.63
technical or vocational school after hi |      1,404        2.73       40.36
                some college, no degree |      8,914       17.36       57.72
  associates or two-year college degree |      4,503        8.77       66.49
               four-year college degree |      9,152       17.82       84.31
graduate or professional school after c |      1,518        2.96       87.27
        graduate or professional degree |      6,247       12.16       99.43
                              dont know |         65        0.13       99.56
                              no answer |        228        0.44      100.00
----------------------------------------+-----------------------------------
                                  Total |     51,356      100.00

----------------------------------------------------------------------------------------------------------------
cw07                                                                                                  us citizen
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw07

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         49542         1  yes
                          1706         2  no
                            11       998  dont know
                            97       999  no answer
*/

gen education =cw06 
recode education 998/999=.
label var education "Education (Scale, 1 to 9)"

gen us_citizen=cw07
recode us_citizen 2=0 998/999=.

/*
----------------------------------------------------------------------------------------------------------------
cw09                                                                                           employment status
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw09

                 range:  [1,999]                      units:  1
         unique values:  10                       missing .:  0/51356


     employment status |      Freq.     Percent        Cum.
-----------------------+-----------------------------------
     working full time |     30,262       58.93       58.93
     working part time |      5,797       11.29       70.21
temporarily unemployed |        899        1.75       71.96
               retired |      8,539       16.63       88.59
  permanently disabled |      1,286        2.50       91.10
             homemaker |      2,996        5.83       96.93
               student |      1,056        2.06       98.99
                 other |        372        0.72       99.71
             dont know |         28        0.05       99.76
             no answer |        121        0.24      100.00
-----------------------+-----------------------------------
                 Total |     51,356      100.00
*/

gen employed=cw09
recode employed 1/2=1 998/999=. *=0
label var employed "Employed (1=yes)"

/*

----------------------------------------------------------------------------------------------------------------
cw14                                                                                   attend religious services
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw14

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          6615         1  more than once a week
                         14250         2  once a week
                          7982         3  once or twice a month
                         13838         4  few times a year
                          8242         5  never
                           107       998  dont know
                           322       999  no answer

*/

gen attend_church=cw14 
recode attend_church 1=4 2=3 3=2 4=1 5=0 *=.
replace attend_church=attend_church
label var attend_church "Religious services attendance (Scale, 0 to 4)

/*

----------------------------------------------------------------------------------------------------------------
cw23                                                                                                      county
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (long)

                 range:  [1001,56045]                 units:  1
         unique values:  2843                     missing .:  0/51356

                  mean:   28736.8
              std. dev:   15795.6

           percentiles:        10%       25%       50%       75%       90%
                              6065     13185     29095     42017     48485


*/

gen county=cw23

/*

----------------------------------------------------------------------------------------------------------------
cw28                                                                                            household income
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw28

                 range:  [1,999]                      units:  1
         unique values:  11                       missing .:  0/51356

              household income |      Freq.     Percent        Cum.
-------------------------------+-----------------------------------
             less than $10,000 |      3,095        6.03        6.03
  $10,000 to less than $15,000 |      3,103        6.04       12.07
  $15,000 to less than $25,000 |      5,795       11.28       23.35
  $25,000 to less than $35,000 |      6,795       13.23       36.58
  $35,000 to less than $50,000 |      8,649       16.84       53.43
  $50,000 to less than $75,000 |      8,723       16.99       70.41
 $75,000 to less than $100,000 |      4,828        9.40       79.81
$100,000 to less than $150,000 |      3,055        5.95       85.76
              $150,000 or more |      1,863        3.63       89.39
                     dont know |      2,115        4.12       93.51
                     no answer |      3,335        6.49      100.00
-------------------------------+-----------------------------------
                         Total |     51,356      100.00

----------------------------------------------------------------------------------------------------------------
cw29                                                                                       labor union household
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw29

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          8129         1  yes
                         42809         2  no
                           311       998  dont know
                           107       999  no answer

*/



gen income=cw28 
recode income 998/999=10
label var income "Income (Scale, 1 to 9, 10=DK/NA)"

gen income_dkna=0
replace income_dkna=1 if income==10
label var income_dkna "Income Don't Know/No Answer"

gen union=cw29
recode union 2=0 998/999=.
label var union "Union Household (1=yes)"

/*

------------------------------------------------------------------------------------------------------------------------------------------
cy06                                                                                  interviewer judge of respondents political knowledge
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cy06

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          8831         1  a
                         18151         2  b
                         15974         3  c
                          5774         4  d
                          2625         5  f
                             1       999  no answer


*/

gen pol_knowledge=cy06
recode pol_knowledge 999=.
replace pol_knowledge=abs(pol_knowledge-5)/4


/*

------------------------------------------------------------------------------------------------------------------------------------------
rk03                                                                                                   interested in presidential campaign
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  rk03

                 range:  [1,999]                      units:  1
         unique values:  5                        missing .:  7160/13171

            tabulation:  Freq.   Numeric  Label
                          2523         1  very interested
                          2319         2  somewhat interested
                          1149         3  not much interested
                            13       998  dont know
                             7       999  no answer
                          7160         .  
*/

gen Rcampaign_interest=rk03
recode Rcampaign_interest 1=2 2=1 3=0 *=.

/*

----------------------------------------------------------------------------------------------------------------
rr23                                                             intended general election ballot, bush vs. gore
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  rr23

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6664/13171

            tabulation:  Freq.   Numeric  Label
                          3005         1  republican
                          2774         2  democrat
                            98         3  other
                           133         4  would not vote for president
                           436       998  dont know
                            61       999  no answer
                          6664         .  

----------------------------------------------------------------------------------------------------------------
rr30                                                                          intend to vote in general election
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  rr30

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  6664/13171

            tabulation:  Freq.   Numeric  Label
                          5930         1  yes
                           437         2  no
                           133       998  dont know
                             7       999  no answer
                          6664         .  


*/

gen Rvoteint=rr30
recode Rvoteint 2=0 3/max=.

gen Rbush_favorability=ra01
replace Rbush_favorability=. if Rbush_favorability>100

gen Rgore_favorability=ra11
replace Rgore_favorability=. if Rgore_favorability>100

gen Rbush_like1=ra02
recode Rbush_like1 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rbush_like2=ra03
recode Rbush_like2 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rbush_like3=ra04
recode Rbush_like3 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rbush_like4=ra05
recode Rbush_like4 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rbush_likes=Rbush_like1+Rbush_like2+Rbush_like3+Rbush_like4

gen Rgore_like1=ra12
recode Rgore_like1 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rgore_like2=ra13
recode Rgore_like2 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rgore_like3=ra14
recode Rgore_like3 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rgore_like4=ra15
recode Rgore_like4 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen Rgore_likes=Rgore_like1+Rgore_like2+Rgore_like3+Rgore_like4

gen Rbush_ideology=(ra09-1)/4
replace Rbush_ideology=. if ra09>5

gen Rgore_ideology=(ra19-1)/4
replace Rgore_ideology=. if ra19>5


compress

save DataFiles\panel_mmn_recoded.dta,replace

clear

****************************************
* Recode Cross Section                 *
****************************************

use DataFiles\CS_mmn.dta, clear

/*

----------------------------------------------------------------------------------------------------------------
cdate                                                                    date of interview (local to respondent)
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (long)

                 range:  [19991214,20001106]          units:  1
         unique values:  322                      missing .:  0/51356

                  mean:   2.0e+07
              std. dev:   1267.07

           percentiles:        10%       25%       50%       75%       90%
                           2.0e+07   2.0e+07   2.0e+07   2.0e+07   2.0e+07

----------------------------------------------------------------------------------------------------------------
cst                                                                                                        state
----------------------------------------------------------------------------------------------------------------

                  type:  string (str2)

         unique values:  49                       missing "":  0/51356

              examples:  "FL"
                         "MD"
                         "NM"
                         "SC"

*/

gen interview_date=cdate
gen state=cst

/*
----------------------------------------------------------------------------------------------------------------
ca09                                                                                bush conservative or liberal
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca09

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  12256/51356

            tabulation:  Freq.   Numeric  Label
                          3730         1  very conservative
                         19137         2  conservative
                          9497         3  moderate
                          3077         4  liberal
                           851         5  very liberal
                          2666       998  dont know
                           142       999  no answer
                         12256         .  

----------------------------------------------------------------------------------------------------------------
ca19                                                                                gore conservative or liberal
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca19

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  12237/51356

            tabulation:  Freq.   Numeric  Label
                          1223         1  very conservative
                          5952         2  conservative
                         12261         3  moderate
                         12077         4  liberal
                          4792         5  very liberal
                          2663       998  dont know
                           151       999  no answer
                         12237         .  
*/

gen bush_ideology=(ca09-1)/4
replace bush_ideology=. if ca09>5

gen gore_ideology=(ca19-1)/4
replace gore_ideology=. if ca19>5

/*

--------------------------------------------------------------------------------------------------------------------------------------------
ca01                                                                                                                      favorability: bush
--------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca01, but 101 nonmissing values are not labeled

                 range:  [0,999]                      units:  1
         unique values:  104                      missing .:  0/51356

              examples:  30    
                         50    
                         75    
                         90    

--------------------------------------------------------------------------------------------------------------------------------------------
ca02                                                                                                                             cares: bush
--------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca02

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          4860         1  extremely well
                         16878         2  quite well
                         12798         3  not too well
                          7875         4  not well
                          2327       998  dont know
                           199       999  no answer
                          6419         .  

------------------------------------------------------------------------------------------------------------------------------------------
ca03                                                                                                                          honest: bush
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca03

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          6455         1  extremely well
                         20186         2  quite well
                         10493         3  not too well
                          4983         4  not well
                          2598       998  dont know
                           222       999  no answer
                          6419         .  

------------------------------------------------------------------------------------------------------------------------------------------
ca04                                                                                                                       inspiring: bush
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca04

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          4633         1  extremely well
                         16477         2  quite well
                         13838         3  not too well
                          7986         4  not well
                          1839       998  dont know
                           164       999  no answer
                          6419         .  

------------------------------------------------------------------------------------------------------------------------------------------
ca05                                                                                                                   knowledgeable: bush
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ca05

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  6419/51356

            tabulation:  Freq.   Numeric  Label
                          6377         1  extremely well
                         23223         2  quite well
                          9317         3  not too well
                          4246         4  not well
                          1623       998  dont know
                           151       999  no answer
                          6419         .  

*/

gen bush_favorability=ca01
replace bush_favorability=. if bush_favorability>100

gen gore_favorability=ca11
replace gore_favorability=. if gore_favorability>100

gen bush_like1=ca02
recode bush_like1 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_like2=ca03
recode bush_like2 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_like3=ca04
recode bush_like3 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_like4=ca05
recode bush_like4 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen bush_likes=bush_like1+bush_like2+bush_like3+bush_like4

gen gore_like1=ca12
recode gore_like1 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_like2=ca13
recode gore_like2 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_like3=ca14
recode gore_like3 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_like4=ca15
recode gore_like4 998=. 999=. .=. 1=1 2=.666 3=.333 4=0

gen gore_likes=gore_like1+gore_like2+gore_like3+gore_like4

/*

------------------------------------------------------------------------------------------------------------------------------------------
ck03                                                                                                   interested in presidential campaign
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  ck03

                 range:  [1,999]                      units:  1
         unique values:  5                        missing .:  30634/51356

            tabulation:  Freq.   Numeric  Label
                          5604         1  very interested
                          8900         2  somewhat interested
                          6115         3  not much interested
                            79       998  dont know
                            24       999  no answer
                         30634         .  


*/

gen campaign_interest=ck03
recode campaign_interest 1=2 2=1 3=0 *=.
replace campaign_interest=campaign_interest/2

/*
----------------------------------------------------------------------------------------------------------------
cr30                                                                          intend to vote in general election
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cr30

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  10058/51356

            tabulation:  Freq.   Numeric  Label
                         35162         1  yes
                          4685         2  no
                          1406       998  dont know
                            45       999  no answer
                         10058         .  

*/

gen voteint=cr30
recode voteint 2=0 3/max=.

/*

----------------------------------------------------------------------------------------------------------------
cv01                                                                                                    party id
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv01

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         14243         1  republican
                         15874         2  democrat
                         14818         3  independent
                          4410         4  verbatim
                          1672       998  dont know
                           339       999  no answer

----------------------------------------------------------------------------------------------------------------
cv02                                                                                             party id strong
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv02

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  6421/51356

            tabulation:  Freq.   Numeric  Label
                         23598         1  strong
                         20394         2  not very strong
                           805       998  dont know
                           138       999  no answer
                          6421         .  

----------------------------------------------------------------------------------------------------------------
cv03                                                                               lean republican or democratic
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv03

                 range:  [1,999]                      units:  1
         unique values:  5                        missing .:  30117/51356

            tabulation:  Freq.   Numeric  Label
                          6665         1  republican
                          7427         2  democratic
                          5553         3  neither
                          1327       998  dont know
                           267       999  no answer
                         30117         .  

*/

gen pid5=.
replace pid5=2 if cv01==1 & cv02==1
replace pid5=1 if cv01==1 & cv02~=1
replace pid5=1 if (cv01==3 | cv01==4 | cv01==998) & cv03==1
replace pid5=0 if (cv01==3 | cv01==4 | cv01==998) & (cv03==3 | cv03==998)
replace pid5=-1 if (cv01==3 | cv01==4 | cv01==998) & cv03==2
replace pid5=-1 if cv01==2 & cv02~=1
replace pid5=-2 if cv01==2 & cv02==1
label var pid5 "Party ID (Scale, +2 Strong R to -2 Strong D)"

/*

----------------------------------------------------------------------------------------------------------------
cv04                                                                                     conservative or liberal
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cv04

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          3263         1  very conservative
                         14865         2  conservative
                         20061         3  moderate
                          9388         4  liberal
                          1996         5  very liberal
                          1535       998  dont know
                           248       999  no answer

*/

gen ideology=cv04
recode ideology 1=2 2=1 3=0 4=-1 5=-2 *=0
label var ideology "Ideology (Scale, +2 Very Consv., -2 Very Lib.)"

/*

----------------------------------------------------------------------------------------------------------------
cw01                                                                                                         sex
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (byte)
                 label:  cw01

                 range:  [1,2]                        units:  1
         unique values:  2                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         22955         1  male
                         28401         2  female

----------------------------------------------------------------------------------------------------------------
cw02                                                                                                         age
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw02, but 80 nonmissing values are not labeled

                 range:  [18,999]                     units:  1
         unique values:  82                       missing .:  0/51356

              examples:  30    
                         40    
                         49    
                         61    

*/

gen female=cw01-1
label var female "Female (1=yes)"
gen age=cw02
recode age 900/max=.
label var age "Age (years)"

/*

----------------------------------------------------------------------------------------------------------------
cw03                                                                                                        race
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw03

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         42173         1  white
                          4511         2  black
                           853         3  asian
                          3052         4  verbatim
                           247       998  dont know
                           520       999  no answer

----------------------------------------------------------------------------------------------------------------
cw04                                                                               of hispanic or spanish origin
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw04

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          4048         1  yes
                         46960         2  no
                           100       998  dont know
                           248       999  no answer

----------------------------------------------------------------------------------------------------------------
cw05                                                                                  hispanic or spanish origin
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw05

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  47308/51356

            tabulation:  Freq.   Numeric  Label
                          2096         1  mexican
                           147         2  cuban
                           474         3  puerto rican
                          1250         4  verbatim
                            54       998  dont know
                            27       999  no answer
                         47308         .  
*/

gen white=cw03
recode white 1=1 2/4=0 *=.
label var white "White (1=yes)"

gen hispanic=0
replace hispanic=1 if cw04==1
replace hispanic=. if cw04>997
label var hispanic "Hispanic (1=yes)"

/*

----------------------------------------------------------------------------------------------------------------
cw06                                                                                                   education
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw06

                 range:  [1,999]                      units:  1
         unique values:  11                       missing .:  0/51356


                              education |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                   grade eight or lower |      1,455        2.83        2.83
           some high school, no diploma |      3,273        6.37        9.21
      high school diploma or equivalent |     14,597       28.42       37.63
technical or vocational school after hi |      1,404        2.73       40.36
                some college, no degree |      8,914       17.36       57.72
  associates or two-year college degree |      4,503        8.77       66.49
               four-year college degree |      9,152       17.82       84.31
graduate or professional school after c |      1,518        2.96       87.27
        graduate or professional degree |      6,247       12.16       99.43
                              dont know |         65        0.13       99.56
                              no answer |        228        0.44      100.00
----------------------------------------+-----------------------------------
                                  Total |     51,356      100.00

----------------------------------------------------------------------------------------------------------------
cw07                                                                                                  us citizen
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw07

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                         49542         1  yes
                          1706         2  no
                            11       998  dont know
                            97       999  no answer
*/

gen education =cw06 
recode education 998/999=.
label var education "Education (Scale, 1 to 9)"

gen us_citizen=cw07
recode us_citizen 2=0 998/999=.

/*
----------------------------------------------------------------------------------------------------------------
cw09                                                                                           employment status
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw09

                 range:  [1,999]                      units:  1
         unique values:  10                       missing .:  0/51356


     employment status |      Freq.     Percent        Cum.
-----------------------+-----------------------------------
     working full time |     30,262       58.93       58.93
     working part time |      5,797       11.29       70.21
temporarily unemployed |        899        1.75       71.96
               retired |      8,539       16.63       88.59
  permanently disabled |      1,286        2.50       91.10
             homemaker |      2,996        5.83       96.93
               student |      1,056        2.06       98.99
                 other |        372        0.72       99.71
             dont know |         28        0.05       99.76
             no answer |        121        0.24      100.00
-----------------------+-----------------------------------
                 Total |     51,356      100.00
*/

gen employed=cw09
recode employed 1/2=1 998/999=. *=0
label var employed "Employed (1=yes)"

/*

----------------------------------------------------------------------------------------------------------------
cw14                                                                                   attend religious services
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw14

                 range:  [1,999]                      units:  1
         unique values:  7                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          6615         1  more than once a week
                         14250         2  once a week
                          7982         3  once or twice a month
                         13838         4  few times a year
                          8242         5  never
                           107       998  dont know
                           322       999  no answer

*/

gen attend_church=cw14 
recode attend_church 1=4 2=3 3=2 4=1 5=0 *=.
replace attend_church=attend_church
label var attend_church "Religious services attendance (Scale, 0 to 4)

/*

----------------------------------------------------------------------------------------------------------------
cw23                                                                                                      county
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (long)

                 range:  [1001,56045]                 units:  1
         unique values:  2843                     missing .:  0/51356

                  mean:   28736.8
              std. dev:   15795.6

           percentiles:        10%       25%       50%       75%       90%
                              6065     13185     29095     42017     48485


*/

gen county=cw23

/*

----------------------------------------------------------------------------------------------------------------
cw28                                                                                            household income
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw28

                 range:  [1,999]                      units:  1
         unique values:  11                       missing .:  0/51356

              household income |      Freq.     Percent        Cum.
-------------------------------+-----------------------------------
             less than $10,000 |      3,095        6.03        6.03
  $10,000 to less than $15,000 |      3,103        6.04       12.07
  $15,000 to less than $25,000 |      5,795       11.28       23.35
  $25,000 to less than $35,000 |      6,795       13.23       36.58
  $35,000 to less than $50,000 |      8,649       16.84       53.43
  $50,000 to less than $75,000 |      8,723       16.99       70.41
 $75,000 to less than $100,000 |      4,828        9.40       79.81
$100,000 to less than $150,000 |      3,055        5.95       85.76
              $150,000 or more |      1,863        3.63       89.39
                     dont know |      2,115        4.12       93.51
                     no answer |      3,335        6.49      100.00
-------------------------------+-----------------------------------
                         Total |     51,356      100.00

----------------------------------------------------------------------------------------------------------------
cw29                                                                                       labor union household
----------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cw29

                 range:  [1,999]                      units:  1
         unique values:  4                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          8129         1  yes
                         42809         2  no
                           311       998  dont know
                           107       999  no answer

*/



gen income=cw28 
recode income 998/999=10
label var income "Income (Scale, 1 to 9, 10=DK/NA)"

gen income_dkna=0
replace income_dkna=1 if income==10
label var income_dkna "Income Don't Know/No Answer"

gen union=cw29
recode union 2=0 998/999=.
label var union "Union Household (1=yes)"

/*

------------------------------------------------------------------------------------------------------------------------------------------
cy06                                                                                  interviewer judge of respondents political knowledge
------------------------------------------------------------------------------------------------------------------------------------------

                  type:  numeric (int)
                 label:  cy06

                 range:  [1,999]                      units:  1
         unique values:  6                        missing .:  0/51356

            tabulation:  Freq.   Numeric  Label
                          8831         1  a
                         18151         2  b
                         15974         3  c
                          5774         4  d
                          2625         5  f
                             1       999  no answer


*/

gen pol_knowledge=cy06
recode pol_knowledge 999=.
replace pol_knowledge=abs(pol_knowledge-5)/4

compress

save DataFiles\CS_mmn_recoded.dta,replace
