/*****************************************************************
* This program replicates the analysis in Huber/Arceneaux 2007.  *
*
* The recoded NAES cross section datasets used by this file      *
* should be in the subdirectory DataFiles                        *
*                                                                *
* April 2007, Gregory Huber and Kevin Arceneaux                  *
*****************************************************************/

#delimit ;
set memory 256m;
set more off;
use DataFiles\CS_mmn_recoded.dta if us_citizen==1;

replace state=lower(state);
drop if state=="dc";

*We analyze the election window, sept 1. to nov. 7.;
drop if month<9;
drop if month>11 | (month==11 & day>=7);

*Label advertising variables;
label var ms4_pro_bush_grp "Pro-Bush Advertising Exposure (GRPs/1000)";
label var ms4_pro_gore_grp "Pro-Gore Advertising Exposure (GRPs/1000)";
label var ms4_presadgrp "Presidential Advertising Exposure (GRPs/1000)";
label var ms4_totaladgrp "Other Campaign Advertising Exposure (GRPs/1000)";

*Drop states with too few observations to reliably estimate state fixed effects/cluster
*N<50;
drop if state=="id" | state=="ms" | state=="mt" | state=="ri" | state=="vt" | state=="wy";

/**************************************************
* generate different competitive state categories *
* VEP=spending, CNN=CNN.                          *
**************************************************/

gen BGVEP=0;
replace BGVEP=1 if state=="ar";
replace BGVEP=1 if state=="de";
replace BGVEP=1 if state=="fl";
replace BGVEP=1 if state=="il";
replace BGVEP=1 if state=="ia";
replace BGVEP=1 if state=="ky";
replace BGVEP=1 if state=="la";
replace BGVEP=1 if state=="me";
replace BGVEP=1 if state=="mi";
replace BGVEP=1 if state=="mn";
replace BGVEP=1 if state=="mo";
replace BGVEP=1 if state=="mt";
replace BGVEP=1 if state=="nv";
replace BGVEP=1 if state=="nh";
replace BGVEP=1 if state=="nm";
replace BGVEP=1 if state=="oh";
replace BGVEP=1 if state=="or";
replace BGVEP=1 if state=="pa";
replace BGVEP=1 if state=="tn";
replace BGVEP=1 if state=="wa";
replace BGVEP=1 if state=="wi";

gen BGCNN=0;
replace BGCNN=1 if state=="az";
replace BGCNN=1 if state=="ar";
replace BGCNN=1 if state=="de";
replace BGCNN=1 if state=="fl";
replace BGCNN=1 if state=="il";
replace BGCNN=1 if state=="ia";
replace BGCNN=1 if state=="la";
replace BGCNN=1 if state=="me";
replace BGCNN=1 if state=="mi";
replace BGCNN=1 if state=="mo";
replace BGCNN=1 if state=="nv";
replace BGCNN=1 if state=="nh";
replace BGCNN=1 if state=="nm";
replace BGCNN=1 if state=="oh";
replace BGCNN=1 if state=="or";
replace BGCNN=1 if state=="pa";
replace BGCNN=1 if state=="tn";
replace BGCNN=1 if state=="wa";
replace BGCNN=1 if state=="wv";
replace BGCNN=1 if state=="wi";

/*****************************************************************************
* Edit the following lines to decide which setup you want to use...          *
*****************************************************************************/

gen BATTLEGROUND=BGVEP;
local suffix="BGVEP";
drop if BATTLEGROUND==1;

quietly tab state, gen(sd_);
*excluded state is California;
drop sd_3;

/*******************************************
* competitive house races, per Cook report *
*******************************************/

gen statecd=upper(state+string(cu01));

gen comphouse=0;
label var comphouse "Competitive House District (1=yes)";
replace comphouse=1 if statecd=="AR4";
replace comphouse=1 if statecd=="CA15";
replace comphouse=1 if statecd=="CA20";
replace comphouse=1 if statecd=="CA27";
replace comphouse=1 if statecd=="CA36";
replace comphouse=1 if statecd=="CA49";
replace comphouse=1 if statecd=="CT2";
replace comphouse=1 if statecd=="CT5";
replace comphouse=1 if statecd=="FL3";
replace comphouse=1 if statecd=="FL8";
replace comphouse=1 if statecd=="FL12";
replace comphouse=1 if statecd=="FL22";
replace comphouse=1 if statecd=="IL10";
replace comphouse=1 if statecd=="IL17";
replace comphouse=1 if statecd=="IN8";
replace comphouse=1 if statecd=="KS3";
replace comphouse=1 if statecd=="KY1";
replace comphouse=1 if statecd=="KY3";
replace comphouse=1 if statecd=="KY6";
replace comphouse=1 if statecd=="MI8";
replace comphouse=1 if statecd=="MN6";
replace comphouse=1 if statecd=="MO6";
replace comphouse=1 if statecd=="MS4";
replace comphouse=1 if statecd=="MT1";
replace comphouse=1 if statecd=="NC8";
replace comphouse=1 if statecd=="NC11";
replace comphouse=1 if statecd=="NH2";
replace comphouse=1 if statecd=="NJ7";
replace comphouse=1 if statecd=="NJ12";
replace comphouse=1 if statecd=="NM1";
replace comphouse=1 if statecd=="NV1";
replace comphouse=1 if statecd=="NY2";
replace comphouse=1 if statecd=="OH12";
replace comphouse=1 if statecd=="OK2";
replace comphouse=1 if statecd=="PA4";
replace comphouse=1 if statecd=="PA10";
replace comphouse=1 if statecd=="PA13";
replace comphouse=1 if statecd=="UT2";
replace comphouse=1 if statecd=="VA2";
replace comphouse=1 if statecd=="WA1";
replace comphouse=1 if statecd=="WA2";
replace comphouse=1 if statecd=="WA5";
replace comphouse=1 if statecd=="WV2";

/*******************************************************************************************
* week dummies for first interview
*******************************************************************************************/

gen temp=mdy(month,day,2000);
gen interviewweekdummy=int((temp-14854)/7);
quietly tab interviewweekdummy, gen(wd_);

*get rid of one week category;
drop wd_1 temp;

/*******************
* Recode variables *
*******************/

gen ms4_bushmargin_grp = ms4_pro_bush-ms4_pro_gore_grp;

gen age2=age*age;
label var age2 "Age Squared";
gen abspid5=abs(pid5);
label var abspid5 "Absolute value of partisanship score";
gen absideology=abs(ideology);
label var absideology "Absolute value ideology score";

gen media_zone_text=string(mmn)+state;
encode media_zone_text, gen(media_zone);

compress;

*Table of summary statistics;
summ ms4_bushmargin_grp ms4_pro_bush_grp ms4_pro_gore_grp ms4_presadgrp ms4_totaladgrp absideology abspid5 pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse, sep(0);

***********************************************************************************************************
* Political Interest and Turnout                                                                          *
***********************************************************************************************************;

log using logs\CSTable1_`suffix'.log, text replace;

oprobit campaign_interest
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcome=.;
replace outcome=0 if o1>o2 & o1>o3 & e(sample);
replace outcome=.5 if o2>o1 & o2>o3 & e(sample);
replace outcome=1 if o3>o1 & o3>o2 & e(sample);
count if e(sample);
count if e(sample) & outcome==campaign_interest;
drop outcome o1 o2 o3;

outreg using logs\CSTable1.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(3) ctitle(`e(depvar)') nonotes replace;

probit voteint
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==voteint;
drop outcome;

outreg using logs\CSTable1.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(3) ctitle(`e(depvar)') nonotes append;

*get summary stats on advertising;
summ ms4_* if e(sample);

log close;

***********************************************************************************************************
* Knowledge: Can you accurately place both candidates on issues on which they took positions              *
***********************************************************************************************************;

gen ACideology=0;
replace ACideology=1 if bush_ideology<gore_ideology;
replace ACideology=. if ca09==. | ca19==.;

gen ACprivatize_ss=0;
replace ACprivatize_ss=1 if cbc07==1 & cbc08==2;
replace ACprivatize_ss=. if cbc07==. | cbc08==.;

gen ACvouchers=0;
replace ACvouchers=1 if cbd05==1 & cbd06==2;
replace ACvouchers=. if cbd05==. | cbd06==.;

gen ACuniversal_hc=0;
replace ACuniversal_hc=1 if cbe09==2 & cbe10==1;
replace ACuniversal_hc=. if cbe09==. | cbe10==.;

gen ACsue_hmo=0;
replace ACsue_hmo=1 if cbe18==2 & cbe19==1;
replace ACsue_hmo=. if cbe18==. | cbe19==.;

gen ACtaxcut=cbb03;
recode ACtaxcut 1=1 2/999=0;

log using logs\CSTable2a_`suffix'.log, text replace;

probit ACprivatize_ss 
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ACprivatize_ss;
drop outcome;

outreg using logs\CSTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

probit ACvouchers
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ACvouchers;
drop outcome;

outreg using logs\CSTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit ACuniversal_hc
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ACuniversal_hc;
drop outcome;

outreg using logs\CSTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit ACsue_hmo
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ACsue_hmo;
drop outcome;

outreg using logs\CSTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit ACideology
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ACideology;
drop outcome;

outreg using logs\CSTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit ACtaxcut
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ACtaxcut;
drop outcome;

outreg using logs\CSTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

log close;

***********************************************************************************************************
* Reinforcement: Do partisans get pulled apart by advertisements?                                         *
***********************************************************************************************************;


*pid5, positive values= republican;

/*
ss_match
school_vouchers_match
universal_hc_match
sue_hmo_match
candidate choice
economy_match (those asked about candidates)
*/

*********************;

gen economy_match=0;
replace economy_match=1 if cba07==1 & (pid5==2 | pid5==1);
replace economy_match=1 if cba07==2 & (pid5==-2 | pid5==-1);
replace economy_match=. if cba07==. | pid5==0;

*********************;

gen ss_match=0;
replace ss_match=1 if cbc05==1 & (pid5==2 | pid5==1);
replace ss_match=1 if cbc05==2 & (pid5==-2 | pid5==-1);
replace ss_match=. if cbc05==. | pid5==0;

*********************;

gen school_vouchers_match=0;
replace school_vouchers_match=1 if cbd02==1 & (pid5==2 | pid5==1);
replace school_vouchers_match=1 if cbd02==2 & (pid5==-2 | pid5==-1);
replace school_vouchers_match=. if cbd02==. | pid5==0;

*********************;

gen universal_hc_match=0;
replace universal_hc_match=1 if cbe08==2 & (pid5==2 | pid5==1);
replace universal_hc_match=1 if cbe08==1 & (pid5==-2 | pid5==-1);
replace universal_hc_match=. if cbe08==. | pid5==0;

*********************;

gen sue_hmo_match=0;
replace sue_hmo_match=1 if cbe14==2 & (pid5==2 | pid5==1);
replace sue_hmo_match=1 if cbe14==1 & (pid5==-2 | pid5==-1);
replace sue_hmo_match=. if cbe14==. | pid5==0;

*********************;

gen vote_match=0;
replace vote_match=1 if cr23==1 & (pid5==2 | pid5==1);
replace vote_match=1 if cr23==2 & (pid5==-2 | pid5==-1);
replace vote_match=. if cr23==. | pid5==0;

*********************;

log using logs\CSTable2b_`suffix'.log, text replace;

probit ss_match
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==ss_match;
drop outcome;

outreg using logs\CSTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

probit school_vouchers_match
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==school_vouchers_match;
drop outcome;

outreg using logs\CSTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit universal_hc_match
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==universal_hc_match;
drop outcome;

outreg using logs\CSTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit sue_hmo_match
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==sue_hmo_match;
drop outcome;

outreg using logs\CSTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit vote_match
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==vote_match;
drop outcome;

outreg using logs\CSTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit economy_match
ms4_presadgrp ms4_totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==economy_match;
drop outcome;

outreg using logs\CSTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

log close;

***********************************************************************************************************
* Favorability, Likeability, and Vote Choice                                                              *
***********************************************************************************************************;

log using logs\CSTable3_`suffix'.log, text replace;

*gen bushminusgorefavor=bush_favorability-gore_favorability;
*gen bushminusgorelikes=bush_likes-gore_likes;

*cr23 is intended vote;
gen BushGoreVoteChoice=.;
replace BushGoreVoteChoice=1 if cr23==1;
replace BushGoreVoteChoice=-1 if cr23==2;
replace BushGoreVoteChoice=0 if cr23==3 | cr23==998;

********;

regress bush_favorability 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

outreg using logs\CSTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

regress gore_favorability 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

outreg using logs\CSTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

gen ct_bush_likes=round(bush_likes*3);

oprobit ct_bush_likes 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

outreg using logs\CSTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o0 o1 o2 o3 o4 o5 o6 o7 o8 o9 o10 o11 o12 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if ct_bush_likes==0 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o0 & e(sample);
replace outcomematch=1 if ct_bush_likes==1 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o1 & e(sample);
replace outcomematch=1 if ct_bush_likes==2 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o2 & e(sample);
replace outcomematch=1 if ct_bush_likes==3 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o3 & e(sample);
replace outcomematch=1 if ct_bush_likes==4 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o4 & e(sample);
replace outcomematch=1 if ct_bush_likes==5 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o5 & e(sample);
replace outcomematch=1 if ct_bush_likes==6 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o6 & e(sample);
replace outcomematch=1 if ct_bush_likes==7 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o7 & e(sample);
replace outcomematch=1 if ct_bush_likes==8 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o8 & e(sample);
replace outcomematch=1 if ct_bush_likes==9 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o9 & e(sample);
replace outcomematch=1 if ct_bush_likes==10 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o10 & e(sample);
replace outcomematch=1 if ct_bush_likes==11 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o11 & e(sample);
replace outcomematch=1 if ct_bush_likes==12 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o12 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o0-o12;

* -> clarify results <- *;

quietly estsimp oprobit ct_bush_likes 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, robust genname(z_);
quietly setx 0;
quietly setx (ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp age) mean;
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 3 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

quietly summ ms4_pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(ms4_pro_bush_grp `from' `to');

quietly summ ms4_pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(ms4_pro_gore_grp `from' `to');

drop z_*;

gen ct_gore_likes=round(gore_likes*3);

oprobit ct_gore_likes 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

outreg using logs\CSTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o0 o1 o2 o3 o4 o5 o6 o7 o8 o9 o10 o11 o12 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if ct_gore_likes==0 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o0 & e(sample);
replace outcomematch=1 if ct_gore_likes==1 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o1 & e(sample);
replace outcomematch=1 if ct_gore_likes==2 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o2 & e(sample);
replace outcomematch=1 if ct_gore_likes==3 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o3 & e(sample);
replace outcomematch=1 if ct_gore_likes==4 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o4 & e(sample);
replace outcomematch=1 if ct_gore_likes==5 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o5 & e(sample);
replace outcomematch=1 if ct_gore_likes==6 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o6 & e(sample);
replace outcomematch=1 if ct_gore_likes==7 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o7 & e(sample);
replace outcomematch=1 if ct_gore_likes==8 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o8 & e(sample);
replace outcomematch=1 if ct_gore_likes==9 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o9 & e(sample);
replace outcomematch=1 if ct_gore_likes==10 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o10 & e(sample);
replace outcomematch=1 if ct_gore_likes==11 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o11 & e(sample);
replace outcomematch=1 if ct_gore_likes==12 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o12 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o0-o12;

* -> clarify results <- *;

quietly estsimp oprobit ct_gore_likes 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, robust genname(z_);

quietly setx 0;
quietly setx (ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp age) mean;
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 3 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

quietly summ ms4_pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(ms4_pro_bush_grp `from' `to');

quietly summ ms4_pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(ms4_pro_gore_grp `from' `to');

drop z_*;

oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

outreg using logs\CSTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if BushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if BushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if BushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

* -> clarify results <- *;

quietly estsimp oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, robust genname(z_);

quietly setx 0;
quietly setx (ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp age) mean;
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 3 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi, msims(5000);

quietly summ ms4_pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(ms4_pro_bush_grp `from' `to')  msims(5000);

quietly summ ms4_pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(ms4_pro_gore_grp `from' `to')  msims(5000);

drop z_*;

***********************************************************************************************************
* Robustness of Vote Choice                                                                               *
***********************************************************************************************************;

*exclude demographics;
oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp comphouse 
wd_* sd_*, cluster(media_zone);

oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

*exclude state dummies;
oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_*, cluster(media_zone);

*exclude week dummies;
oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_*, cluster(media_zone);

*Allow non-linear effects;
gen ms4_pro_bush_grp2=ms4_pro_bush_grp^2;
gen ms4_pro_gore_grp2=ms4_pro_gore_grp^2;

oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_bush_grp2 ms4_pro_gore_grp ms4_pro_gore_grp2 ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

*accounting for overall volume;
gen ms4_pro_bush_volume=ms4_pro_bush_grp*ms4_presadgrp;
gen ms4_pro_gore_volume=ms4_pro_gore_grp*ms4_presadgrp;

oprobit BushGoreVoteChoice 
ms4_pro_bush_grp ms4_pro_bush_volume ms4_pro_gore_grp ms4_pro_gore_volume ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_*, cluster(media_zone);

*exclude each state;

encode state, gen(stnum);

oprobit BushGoreVoteChoice
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_* if stnum~=1, cluster(media_zone);
outreg using logs\CSTable3DroppingStates.out, nocons noaster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

local ctr=2;
while `ctr'<=20 {;
oprobit BushGoreVoteChoice
ms4_pro_bush_grp ms4_pro_gore_grp ms4_totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_* sd_* if stnum~=`ctr', cluster(media_zone);
outreg using logs\CSTable3DroppingStates.out, nocons noaster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;
local ctr=`ctr'+1;
};

log close;
