/*****************************************************************
* This program replicates the analysis in Huber/Arceneaux 2007.  *
*
* The recoded NAES cross section datasets used by this file      *
* should be in the subdirectory DataFiles                        *
*                                                                *
* April 2007, Gregory Huber and Kevin Arceneaux                  *
*****************************************************************/

#delimit ;
set memory 256m;
set more off;
use DataFiles\panel_mmn_recoded.dta if us_citizen==1;

replace state=lower(state);
drop if state=="dc";

*Label advertising variables;
label var pro_bush_grp "Pro-Bush Advertising Exposure (GRPs/1000)";
label var pro_gore_grp "Pro-Gore Advertising Exposure (GRPs/1000)";
label var presadgrp "Presidential Advertising Exposure (GRPs/1000)";
label var totaladgrp "Other Campaign Advertising Exposure (GRPs/1000)";

*Drop states with too few observations to reliably estimate state fixed effects/cluster;
drop if state=="id" | state=="ms" | state=="mt" | state=="ne" | state=="vt" | state=="wy";

/**************************************************
* generate different competitive state categories *
* VEP=spending, CNN=CNN.                          *
**************************************************/

gen BGVEP=0;
replace BGVEP=1 if state=="ar";
replace BGVEP=1 if state=="de";
replace BGVEP=1 if state=="fl";
replace BGVEP=1 if state=="il";
replace BGVEP=1 if state=="ia";
replace BGVEP=1 if state=="ky";
replace BGVEP=1 if state=="la";
replace BGVEP=1 if state=="me";
replace BGVEP=1 if state=="mi";
replace BGVEP=1 if state=="mn";
replace BGVEP=1 if state=="mo";
replace BGVEP=1 if state=="mt";
replace BGVEP=1 if state=="nv";
replace BGVEP=1 if state=="nh";
replace BGVEP=1 if state=="nm";
replace BGVEP=1 if state=="oh";
replace BGVEP=1 if state=="or";
replace BGVEP=1 if state=="pa";
replace BGVEP=1 if state=="tn";
replace BGVEP=1 if state=="wa";
replace BGVEP=1 if state=="wi";

gen BGCNN=0;
replace BGCNN=1 if state=="az";
replace BGCNN=1 if state=="ar";
replace BGCNN=1 if state=="de";
replace BGCNN=1 if state=="fl";
replace BGCNN=1 if state=="il";
replace BGCNN=1 if state=="ia";
replace BGCNN=1 if state=="la";
replace BGCNN=1 if state=="me";
replace BGCNN=1 if state=="mi";
replace BGCNN=1 if state=="mo";
replace BGCNN=1 if state=="nv";
replace BGCNN=1 if state=="nh";
replace BGCNN=1 if state=="nm";
replace BGCNN=1 if state=="oh";
replace BGCNN=1 if state=="or";
replace BGCNN=1 if state=="pa";
replace BGCNN=1 if state=="tn";
replace BGCNN=1 if state=="wa";
replace BGCNN=1 if state=="wv";
replace BGCNN=1 if state=="wi";

/*****************************************************************************
* Edit the following lines to decide which setup you want to use...          *
*****************************************************************************/

gen BATTLEGROUND=BGVEP;
local suffix="BGVEP";
drop if BATTLEGROUND==1;

quietly tab state, gen(sd_);
*excluded state is California;
drop sd_3;

/*******************************************
* competitive house races, per Cook report *
*******************************************/

gen statecd=upper(state+string(cu01));

gen comphouse=0;
label var comphouse "Competitive House District (1=yes)";
replace comphouse=1 if statecd=="AR4";
replace comphouse=1 if statecd=="CA15";
replace comphouse=1 if statecd=="CA20";
replace comphouse=1 if statecd=="CA27";
replace comphouse=1 if statecd=="CA36";
replace comphouse=1 if statecd=="CA49";
replace comphouse=1 if statecd=="CT2";
replace comphouse=1 if statecd=="CT5";
replace comphouse=1 if statecd=="FL3";
replace comphouse=1 if statecd=="FL8";
replace comphouse=1 if statecd=="FL12";
replace comphouse=1 if statecd=="FL22";
replace comphouse=1 if statecd=="IL10";
replace comphouse=1 if statecd=="IL17";
replace comphouse=1 if statecd=="IN8";
replace comphouse=1 if statecd=="KS3";
replace comphouse=1 if statecd=="KY1";
replace comphouse=1 if statecd=="KY3";
replace comphouse=1 if statecd=="KY6";
replace comphouse=1 if statecd=="MI8";
replace comphouse=1 if statecd=="MN6";
replace comphouse=1 if statecd=="MO6";
replace comphouse=1 if statecd=="MS4";
replace comphouse=1 if statecd=="MT1";
replace comphouse=1 if statecd=="NC8";
replace comphouse=1 if statecd=="NC11";
replace comphouse=1 if statecd=="NH2";
replace comphouse=1 if statecd=="NJ7";
replace comphouse=1 if statecd=="NJ12";
replace comphouse=1 if statecd=="NM1";
replace comphouse=1 if statecd=="NV1";
replace comphouse=1 if statecd=="NY2";
replace comphouse=1 if statecd=="OH12";
replace comphouse=1 if statecd=="OK2";
replace comphouse=1 if statecd=="PA4";
replace comphouse=1 if statecd=="PA10";
replace comphouse=1 if statecd=="PA13";
replace comphouse=1 if statecd=="UT2";
replace comphouse=1 if statecd=="VA2";
replace comphouse=1 if statecd=="WA1";
replace comphouse=1 if statecd=="WA2";
replace comphouse=1 if statecd=="WA5";
replace comphouse=1 if statecd=="WV2";

/******************************
* dummies for campaign events *
*******************************

gopconv
.  disp mdy(7,31,2000)
14822

demconv
.  disp mdy(8,14,2000)
14836

debate1
. disp mdy(10,3,2000)
14886

debate2
. disp mdy(10,11,2000)
14894

debate3
. disp mdy(10,17,2000)
14900
*******************************/

gen event_gopconv=0;
replace event_gopconv=1 if firstdate<14822 & seconddate>14822;
label var event_gopconv "Event Indicator: Rep. Convention";

gen event_demconv=0;
replace event_demconv=1 if firstdate<14836 & seconddate>14836;
label var event_demconv "Event Indicator: Dem. Convention";

gen event_debate1=0;
replace event_debate1=1 if firstdate<14886 & seconddate>14886;
label var event_debate1 "Event Indicator: 1st debate";

gen event_debate2=0;
replace event_debate2=1 if firstdate<14894 & seconddate>14894;
label var event_debate2 "Event Indicator: 2nd debate";

gen event_debate3=0;
replace event_debate3=1 if firstdate<14900 & seconddate>14900;
label var event_debate3 "Event Indicator: 3rd debate";

/*******************************************************************************************
* week dummies for second interview, grouping together everyone interviewed after election *
*******************************************************************************************/

gen temp=seconddate;
replace temp=14922 if temp>14922 & temp~=.;
gen reinterviewweekdummy=int((temp-14792)/7);
quietly tab reinterviewweekdummy, gen(wd_);

*get rid of post-electiond interview dummy for excluded category;
drop wd_11;

/*******************
* Recode variables *
*******************/

gen bushmargin_grp = pro_bush-pro_gore_grp;

gen age2=age*age;
label var age2 "Age Squared";
gen abspid5=abs(pid5);
label var abspid5 "Absolute value of partisanship score";
gen absideology=abs(ideology);
label var absideology "Absolute value ideology score";

gen media_zone_text=string(mmn)+state;
encode media_zone_text, gen(media_zone);

gen days=seconddate-firstdate;
label var days "Days in panel";

compress;

*Table of summary statistics;
summ bushmargin_grp pro_bush_grp pro_gore_grp  presadgrp totaladgrp absideology abspid5 pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse days event_*, sep(0);

***********************************************************************************************************
* Political Interest and Turnout                                                                          *
***********************************************************************************************************;

log using logs\PanelTable1_`suffix'.log, text replace;

*for change from previous period, create dummies rather than using numerical values for 2 question items;
quietly tab campaign_interest, gen(c_campaign_interest_);

oprobit Rcampaign_interest c_campaign_interest_1 c_campaign_interest_2
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcome=.;
replace outcome=0 if o1>o2 & o1>o3 & e(sample);
replace outcome=.5 if o2>o1 & o2>o3 & e(sample);
replace outcome=1 if o3>o1 & o3>o2 & e(sample);
count if e(sample);
count if e(sample) & outcome==Rcampaign_interest;
drop outcome o1 o2 o3;

outreg using logs\PanelTable1.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(3) ctitle(`e(depvar)') nonotes replace;

probit Rvoteint voteint
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==Rvoteint;
drop outcome;

outreg using logs\PanelTable1.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(3) ctitle(`e(depvar)') nonotes append;

*get summary stats on advertising;
summ presadgrp totaladgrp if e(sample);

log close;

***********************************************************************************************************
* Knowledge: Can you accurately place both candidates on issues on which they took positions              *
***********************************************************************************************************;

gen ACprivatize_ss=0;
replace ACprivatize=1 if cbc07==1 & cbc08==2;
replace ACprivatize=. if cbc07==. | cbc08==.;

gen ACvouchers=0;
replace ACvouchers=1 if cbd05==1 & cbd06==2;
replace ACvouchers=. if cbd05==. | cbd06==.;

gen ACuniversal_hc=0;
replace ACuniversal_hc=1 if cbe09==2 & cbe10==1;
replace ACuniversal_hc=. if cbe09==. | cbe10==.;

gen ACsue_hmo=0;
replace ACsue_hmo=1 if cbe18==2 & cbe19==1;
replace ACsue_hmo=. if cbe18==. | cbe19==.;

gen ACideology=0;
replace ACideology=1 if bush_ideology<gore_ideology;
replace ACideology=. if ca09==. | ca19==.;

gen ACtaxcut=cbb03;
recode ACtaxcut 1=1 2/999=0;

gen RACprivatize_ss=0;
replace RACprivatize_ss=1 if rbc07==1 & rbc08==2;
replace RACprivatize_ss=. if rbc07==. | rbc08==.;

gen RACvouchers=0;
replace RACvouchers=1 if rbd05==1 & rbd06==2;
replace RACvouchers=. if rbd05==. | rbd06==.;

gen RACuniversal_hc=0;
replace RACuniversal_hc=1 if rbe09==2 & rbe10==1;
replace RACuniversal_hc=. if rbe09==. | rbe10==.;

gen RACsue_hmo=0;
replace RACsue_hmo=1 if rbe18==2 & rbe19==1;
replace RACsue_hmo=. if rbe18==. | rbe19==.;

gen RACideology=0;
replace RACideology=1 if Rbush_ideology<Rgore_ideology;
replace RACideology=. if ra09==. | ra19==.;

gen RACtaxcut=rbb03;
recode RACtaxcut 1=1 2/999=0;

log using logs\PanelTable2a_`suffix'.log, text replace;

probit RACprivatize_ss ACprivatize_ss 
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACprivatize_ss;
drop outcome;

outreg using logs\PanelTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

* -> clarify results <- *;

quietly estsimp probit RACprivatize_ss ACprivatize_ss 
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, robust genname(z_);

quietly setx 0;
quietly setx (presadgrp totaladgrp) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx absideology 0 abspid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

quietly summ presadgrp;
quietly local from=(r(mean));
quietly local to=(r(mean)+r(sd));
simqi, fd(pr) changex(presadgrp `from' `to');

drop z_*;

probit RACvouchers ACvouchers
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACvouchers;
drop outcome;

outreg using logs\PanelTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACuniversal_hc ACuniversal_hc
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACuniversal_hc;
drop outcome;

outreg using logs\PanelTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACsue_hmo ACsue_hmo
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACsue_hmo;
drop outcome;

outreg using logs\PanelTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACideology ACideology
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACideology;
drop outcome;

outreg using logs\PanelTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACtaxcut ACtaxcut
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACtaxcut;
drop outcome;

outreg using logs\PanelTable2a.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

log close;

***********************************************************************************************************
* Knowledge Robustness: Were people interviewed earlier in the campaign more susceptible to learning?     *
***********************************************************************************************************;

*this restricts to people interviewed before august,1, 2000:
if firstdate<mdy(08,01,2000);

log using logs\PanelTable2aRobustness_`suffix'.log, text replace;

probit RACprivatize_ss ACprivatize_ss 
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate<mdy(08,01,2000), cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACprivatize_ss;
drop outcome;

outreg using logs\PanelTable2aRobustness.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

probit RACvouchers ACvouchers
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate<mdy(08,01,2000), cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACvouchers;
drop outcome;

outreg using logs\PanelTable2aRobustness.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACuniversal_hc ACuniversal_hc
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate<mdy(08,01,2000), cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACuniversal_hc;
drop outcome;

outreg using logs\PanelTable2aRobustness.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACsue_hmo ACsue_hmo
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate<mdy(08,01,2000), cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACsue_hmo;
drop outcome;

outreg using logs\PanelTable2aRobustness.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACideology ACideology
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate<mdy(08,01,2000), cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACideology;
drop outcome;

outreg using logs\PanelTable2aRobustness.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit RACtaxcut ACtaxcut
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate<mdy(08,01,2000), cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==RACtaxcut;
drop outcome;

outreg using logs\PanelTable2aRobustness.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

log close;

***********************************************************************************************************
* Reinforcement: Do partisans get pulled apart by advertisements?                                         *
***********************************************************************************************************;

*pid5, positive values= republican;

/*
ss_match
school_vouchers_match
universal_hc_match
sue_hmo_match
candidate choice
*/

*********************;

gen ss_match=0;
replace ss_match=1 if cbc05==1 & (pid5==2 | pid5==1);
replace ss_match=1 if cbc05==2 & (pid5==-2 | pid5==-1);
replace ss_match=. if cbc05==. | pid5==0;

*********************;

gen school_vouchers_match=0;
replace school_vouchers_match=1 if cbd02==1 & (pid5==2 | pid5==1);
replace school_vouchers_match=1 if cbd02==2 & (pid5==-2 | pid5==-1);
replace school_vouchers_match=. if cbd02==. | pid5==0;

*********************;

gen universal_hc_match=0;
replace universal_hc_match=1 if cbe08==2 & (pid5==2 | pid5==1);
replace universal_hc_match=1 if cbe08==1 & (pid5==-2 | pid5==-1);
replace universal_hc_match=. if cbe08==. | pid5==0;

*********************;

gen sue_hmo_match=0;
replace sue_hmo_match=1 if cbe14==2 & (pid5==2 | pid5==1);
replace sue_hmo_match=1 if cbe14==1 & (pid5==-2 | pid5==-1);
replace sue_hmo_match=. if cbe14==. | pid5==0;

*********************;

gen vote_match=0;
replace vote_match=1 if cr23==1 & (pid5==2 | pid5==1);
replace vote_match=1 if cr23==2 & (pid5==-2 | pid5==-1);
replace vote_match=. if cr23==. | pid5==0;

*********************;

gen Rss_match=0;
replace Rss_match=1 if rbc05==1 & (pid5==2 | pid5==1);
replace Rss_match=1 if rbc05==2 & (pid5==-2 | pid5==-1);
replace Rss_match=. if rbc05==. | pid5==0;

*********************;

gen Rschool_vouchers_match=0;
replace Rschool_vouchers_match=1 if rbd02==1 & (pid5==2 | pid5==1);
replace Rschool_vouchers_match=1 if rbd02==2 & (pid5==-2 | pid5==-1);
replace Rschool_vouchers_match=. if rbd02==. | pid5==0;

*********************;

gen Runiversal_hc_match=0;
replace Runiversal_hc_match=1 if rbe08==2 & (pid5==2 | pid5==1);
replace Runiversal_hc_match=1 if rbe08==1 & (pid5==-2 | pid5==-1);
replace Runiversal_hc_match=. if rbe08==. | pid5==0;

*********************;

gen Rsue_hmo_match=0;
replace Rsue_hmo_match=1 if rbe14==2 & (pid5==2 | pid5==1);
replace Rsue_hmo_match=1 if rbe14==1 & (pid5==-2 | pid5==-1);
replace Rsue_hmo_match=. if rbe14==. | pid5==0;

*********************;

gen Rvote_match=0;
replace Rvote_match=1 if rr23==1 & (pid5==2 | pid5==1);
replace Rvote_match=1 if rr23==2 & (pid5==-2 | pid5==-1);
replace Rvote_match=. if rr23==. | pid5==0;

*********************;

log using logs\PanelTable2b_`suffix'.log, text replace;

probit Rss_match ss_match 
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==Rss_match;
drop outcome;

outreg using logs\PanelTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

* -> clarify results <- *;

quietly estsimp probit Rss_match ss_match 
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, robust genname(z_);

quietly setx 0;
quietly setx (presadgrp totaladgrp) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx absideology 0 abspid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

quietly summ presadgrp;
quietly local from=(r(mean));
quietly local to=(r(mean)+r(sd));
simqi, fd(pr) changex(presadgrp `from' `to');

drop z_*;

probit Rschool_vouchers_match school_vouchers_match
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==Rschool_vouchers_match;
drop outcome;

outreg using logs\PanelTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit Runiversal_hc_match universal_hc_match
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==Runiversal_hc_match;
drop outcome;

outreg using logs\PanelTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit Rsue_hmo_match sue_hmo_match
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==Rsue_hmo_match;
drop outcome;

outreg using logs\PanelTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

probit Rvote_match vote_match
presadgrp totaladgrp absideology abspid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

* -> % correctly predicted;

predict outcome if e(sample);
replace outcome=0 if outcome<=.5 & e(sample);
replace outcome=1 if outcome>=.5 & e(sample);
count if e(sample);
count if e(sample) & outcome==Rvote_match;
drop outcome;

outreg using logs\PanelTable2b.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

log close;

***********************************************************************************************************
* Favorability, Likeability, and Vote Choice                                                              *
***********************************************************************************************************;

log using logs\PanelTable3_`suffix'.log, text replace;

*gen bushminusgorefavor=bush_favorability-gore_favorability;
*gen bushminusgorelikes=bush_likes-gore_likes;

*cr23 is intended vote;
gen BushGoreVoteChoice=.;
replace BushGoreVoteChoice=1 if cr23==1;
replace BushGoreVoteChoice=-1 if cr23==2;
replace BushGoreVoteChoice=0 if cr23==3 | cr23==998;
quietly tab BushGoreVoteChoice, gen(bgvc_);
drop bgvc_2;

*rr23 is intended vote;
gen RBushGoreVoteChoice=.;
replace RBushGoreVoteChoice=1 if rr23==1;
replace RBushGoreVoteChoice=-1 if rr23==2;
replace RBushGoreVoteChoice=0 if rr23==3 | rr23==998;

********;

regress Rbush_favorability bush_favorability 
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

regress Rgore_favorability gore_favorability 
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

gen ct_bush_likes=round(bush_likes*3);
quietly tab ct_bush_likes, gen(ctbl_);
drop ctbl_7;
gen Rct_bush_likes=round(Rbush_likes*3);

oprobit Rct_bush_likes ctbl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o0 o1 o2 o3 o4 o5 o6 o7 o8 o9 o10 o11 o12 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if Rct_bush_likes==0 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o0 & e(sample);
replace outcomematch=1 if Rct_bush_likes==1 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o1 & e(sample);
replace outcomematch=1 if Rct_bush_likes==2 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o2 & e(sample);
replace outcomematch=1 if Rct_bush_likes==3 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o3 & e(sample);
replace outcomematch=1 if Rct_bush_likes==4 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o4 & e(sample);
replace outcomematch=1 if Rct_bush_likes==5 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o5 & e(sample);
replace outcomematch=1 if Rct_bush_likes==6 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o6 & e(sample);
replace outcomematch=1 if Rct_bush_likes==7 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o7 & e(sample);
replace outcomematch=1 if Rct_bush_likes==8 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o8 & e(sample);
replace outcomematch=1 if Rct_bush_likes==9 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o9 & e(sample);
replace outcomematch=1 if Rct_bush_likes==10 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o10 & e(sample);
replace outcomematch=1 if Rct_bush_likes==11 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o11 & e(sample);
replace outcomematch=1 if Rct_bush_likes==12 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o12 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o0-o12;

* -> clarify results <- *;

quietly estsimp oprobit Rct_bush_likes ctbl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, robust genname(z_);

quietly setx 0;
quietly setx (pro_bush_grp pro_gore_grp totaladgrp days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

quietly summ pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(pro_bush_grp `from' `to');

quietly summ pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(pro_gore_grp `from' `to');

drop z_*;

gen ct_gore_likes=round(gore_likes*3);
quietly tab ct_gore_likes, gen(ctgl_);
drop ctgl_7;
gen Rct_gore_likes=round(Rgore_likes*3);

oprobit Rct_gore_likes ctgl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o0 o1 o2 o3 o4 o5 o6 o7 o8 o9 o10 o11 o12 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if Rct_gore_likes==0 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o0 & e(sample);
replace outcomematch=1 if Rct_gore_likes==1 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o1 & e(sample);
replace outcomematch=1 if Rct_gore_likes==2 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o2 & e(sample);
replace outcomematch=1 if Rct_gore_likes==3 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o3 & e(sample);
replace outcomematch=1 if Rct_gore_likes==4 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o4 & e(sample);
replace outcomematch=1 if Rct_gore_likes==5 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o5 & e(sample);
replace outcomematch=1 if Rct_gore_likes==6 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o6 & e(sample);
replace outcomematch=1 if Rct_gore_likes==7 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o7 & e(sample);
replace outcomematch=1 if Rct_gore_likes==8 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o8 & e(sample);
replace outcomematch=1 if Rct_gore_likes==9 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o9 & e(sample);
replace outcomematch=1 if Rct_gore_likes==10 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o10 & e(sample);
replace outcomematch=1 if Rct_gore_likes==11 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o11 & e(sample);
replace outcomematch=1 if Rct_gore_likes==12 & max(o0,o1,o2,o3,o4,o6,o7,o8,o9,o10,o11,o12)==o12 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o0-o12;

* -> clarify results <- *;

quietly estsimp oprobit Rct_gore_likes ctgl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, robust genname(z_);

quietly setx 0;
quietly setx (pro_bush_grp pro_gore_grp totaladgrp days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

quietly summ pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(pro_bush_grp `from' `to');

quietly summ pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(pro_gore_grp `from' `to');

drop z_*;

oprobit RBushGoreVoteChoice bgvc_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable3.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

* -> clarify results <- *;

quietly estsimp oprobit RBushGoreVoteChoice bgvc_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_1-wd_5 wd_7-wd_10 sd_*, robust genname(z_);

quietly setx 0;
quietly setx (pro_bush_grp pro_gore_grp totaladgrp days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi, msims(5000);

quietly summ pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(pro_bush_grp `from' `to')  msims(5000);

quietly summ pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+1.57);
simqi, fd(pr) changex(pro_gore_grp `from' `to')  msims(5000);

drop z_*;

*Several extensions to vote choice model:

*likeability effects before Nov, 7, 2000;

oprobit Rct_bush_likes ctbl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if seconddate<=mdy(11,7,2000), cluster(media_zone);

oprobit Rct_gore_likes ctgl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if seconddate<=mdy(11,7,2000), cluster(media_zone);

*likeability effects after Sept, 1, 2000;

oprobit Rct_bush_likes ctbl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate>=mdy(9,1,2000), cluster(media_zone);

oprobit Rct_gore_likes ctgl_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if firstdate>=mdy(9,1,2000), cluster(media_zone);

log close;

***********************************************************************************************************
* vote Choice, Mechanism                                                                                  *
***********************************************************************************************************;

log using logs\PanelTable4_`suffix'.log, text replace;

*To discern the mechanism, we want to consider many different ways in which ads can work;

/*******************
*Code new variables*
*******************/

*The first is affect, e.g. favorability and likability;

gen delta_bush_favorabilitymargin=(Rbush_favorability-Rgore_favorability)-(bush_favorability-gore_favorability);
gen delta_bush_likesmargin=(Rbush_likes-Rgore_likes)-(bush_likes-gore_likes);
label var delta_bush_favorabilitymargin "Change in Bush Favorability Margin";
label var delta_bush_likesmargin "Change in Bush Likeability Margin";

summ delta_bush_favorabilitymargin delta_bush_likesmargin;

*The second is accuracy of placement on social security privatization. We take people who've become accurate and consider the effect
 of their prior opinion*;

gen became_accurate_ss=.;
replace became_accurate_ss=0 if (ACprivatize_ss~=. & RACprivatize_ss~=.);
replace became_accurate_ss=1 if ACprivatize_ss==0 & RACprivatize_ss==1;
label var became_accurate_ss "Became Accurate on Social Security Positions";

gen privss=0;
replace privss=1 if cbc05==1;
replace privss=-1 if cbc05==2;
replace privss=0 if cbc05==.;
label var privss "Support 'Personal' Social Security Accounts";

gen privss_becomeaccurate=privss*became_accurate_ss;
label var privss_becomeaccurate "Became Accurate on Social Security Positions*Support 'Personal' Social Security Accounts";

*The third is reinforcement, where we want to code reinforcement on social security privatization
 in a directional manner;

gen become_reinforced_ss=.;
replace become_reinforced_ss=0 if (ss_match~=. & Rss_match~=.);
replace become_reinforced_ss=1 if (ss_match==0 & Rss_match==1);
label var become_reinforced_ss "Adopted Party's Position on Social Security";

gen pid5become_reinforced_ss=become_reinforced_ss*pid5;
label var pid5become_reinforced_ss "Adopted Party's Position on Social Security*Partisanship";

/*******************
*End Coding        *
*******************/

/*******************
*Models            *
*******************/

*affect mechanism;

oprobit RBushGoreVoteChoice bgvc_*
delta_bush_favorabilitymargin delta_bush_likesmargin 
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable4.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

* -> clarify results <- *;

quietly estsimp oprobit RBushGoreVoteChoice bgvc_*
delta_bush_favorabilitymargin delta_bush_likesmargin 
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_1-wd_5 wd_7-wd_10 sd_*, robust genname(z_);

quietly setx 0;
quietly setx (days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 
simqi;

simqi, fd(pr) changex(delta_bush_favorabilitymargin 0 30.4);
simqi, fd(pr) changex(delta_bush_likesmargin 0 .93);
drop z_*;

*accuracy of candidate placement on social secuity given prior policy opinion in that area;

oprobit RBushGoreVoteChoice bgvc_*
became_accurate_ss privss privss_becomeaccurate 
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable4.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

*reinforcement of partisan positions on social secuity;

oprobit RBushGoreVoteChoice bgvc_* 
become_reinforced_ss pid5become_reinforced_ss 
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse
days event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable4.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

* -> clarify results <- *;

quietly estsimp oprobit RBushGoreVoteChoice bgvc_* 
become_reinforced_ss pid5become_reinforced_ss 
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_1-wd_5 wd_7-wd_10 sd_*, robust genname(z_);

quietly setx 0;
quietly setx (days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 
simqi;

setx pid5 2;
simqi;
simqi, fd(pr) changex(become_reinforced_ss 0 1 pid5become_reinforced_ss 0 2);
setx pid5 -2;
simqi;
simqi, fd(pr) changex(become_reinforced_ss 0 1 pid5become_reinforced_ss 0 -2);

drop z_*;

*all together with ads;

oprobit RBushGoreVoteChoice bgvc_*  
pro_bush_grp pro_gore_grp totaladgrp delta_bush_favorabilitymargin delta_bush_likesmargin  
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);
*We want to run the base advertising model on the same sample, so set that here.;
gen runsample=e(sample);

outreg using logs\PanelTable4.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

*just ads;

oprobit RBushGoreVoteChoice bgvc_*  
pro_bush_grp pro_gore_grp totaladgrp  
ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if runsample, cluster(media_zone);

outreg using logs\PanelTable4.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

*now, for the Sobel-Goodman mediation tests, we need just a single variable, so we transform advertising to bushmargin_grp
*likewise, we can only test favorability and likeability sep.;
sgmediation RBushGoreVoteChoice if runsample, mv(delta_bush_favor) iv(bushmargin_grp)
cv(bgvc_* presadgrp totaladgrp ideology pid5 attend_church union income income_dkna employed education 
hispanic white female age age2 comphouse days event_* wd_* sd_*);

sgmediation RBushGoreVoteChoice if runsample, mv(delta_bush_like) iv(bushmargin_grp)
cv(bgvc_* presadgrp totaladgrp ideology pid5 attend_church union income income_dkna employed education 
hispanic white female age age2 comphouse days event_* wd_* sd_*);

log close;

***********************************************************************************************************
* Vote Choice, Zaller method by sophistication/education and interest                                     *
***********************************************************************************************************;

log using logs\PanelTable5_`suffix'.log, text replace;

/******************************
* By prior Education          *
******************************/

gen probush_grp_ed0=0;
gen progore_grp_ed0=0;
gen probush_grp_ed1=0;
gen progore_grp_ed1=0;
gen probush_grp_ed2=0;
gen progore_grp_ed2=0;
gen probush_grp_ed3=0;
gen progore_grp_ed3=0;

replace probush_grp_ed0=pro_bush_grp if (education==1 | education==2 | education==3);
replace progore_grp_ed0=pro_gore_grp if (education==1 | education==2 | education==3);

replace probush_grp_ed1=pro_bush_grp if (education==4 | education==5 | education==6);
replace progore_grp_ed1=pro_gore_grp if (education==4 | education==5 | education==6);

replace probush_grp_ed2=pro_bush_grp if (education==7);
replace progore_grp_ed2=pro_gore_grp if (education==7);

replace probush_grp_ed3=pro_bush_grp if (education==8 | education==9);
replace progore_grp_ed3=pro_gore_grp if (education==8 | education==9);

tab education, gen (edcat_);
drop edcat_1;

oprobit RBushGoreVoteChoice bgvc_*
probush_grp_ed* progore_grp_ed* totaladgrp ideology pid5 attend_church union income income_dkna employed edcat_* hispanic white female age age2 comphouse days 
event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable5.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

* -> clarify results <- *;

quietly estsimp oprobit RBushGoreVoteChoice bgvc_*
probush_grp_ed* progore_grp_ed* totaladgrp ideology pid5 attend_church union income income_dkna employed edcat_* hispanic white female age age2 comphouse days 
event_* wd_1-wd_5 wd_7-wd_10 sd_*, robust genname(z_);

quietly setx 0;
quietly setx (totaladgrp days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 
setx (edcat_2) 1;

simqi;

summ pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+r(sd));
setx edcat_2 1;
setx probush_grp_ed0 `from';
simqi;
simqi, fd(pr) changex(probush_grp_ed0 `from' `to');
setx edcat_2 0 edcat_5 1;
setx probush_grp_ed0 0 probush_grp_ed1 `from';
simqi;
simqi, fd(pr) changex(probush_grp_ed1 `from' `to');
setx probush_grp_ed1 0 probush_grp_ed2 `from';
setx edcat_5 0 edcat_7 1;
simqi;
simqi, fd(pr) changex(probush_grp_ed2 `from' `to');
setx probush_grp_ed2 0 probush_grp_ed3 `from';
setx edcat_7 0 edcat_9 1;
simqi;
simqi, fd(pr) changex(probush_grp_ed3 `from' `to');
setx edcat_9 0 probush_grp_ed3 0;

summ pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+r(sd));
setx edcat_2 1;
setx progore_grp_ed0 `from';
simqi;
simqi, fd(pr) changex(progore_grp_ed0 `from' `to');
setx edcat_2 0 edcat_5 1;
setx progore_grp_ed0 0 progore_grp_ed1 `from';
simqi;
simqi, fd(pr) changex(progore_grp_ed1 `from' `to');
setx progore_grp_ed1 0 progore_grp_ed2 `from';
setx edcat_5 0 edcat_7 1;
simqi;
simqi, fd(pr) changex(progore_grp_ed2 `from' `to');
setx progore_grp_ed2 0 progore_grp_ed3 `from';
setx edcat_7 0 edcat_9 1;
simqi;
simqi, fd(pr) changex(progore_grp_ed3 `from' `to');
setx edcat_9 0 progore_grp_ed3 0;

drop z_*;

/******************************
* By prior political interest *
******************************/

gen probush_grp_pi0=0;
gen progore_grp_pi0=0;
gen probush_grp_pi1=0;
gen progore_grp_pi1=0;
gen probush_grp_pi2=0;
gen progore_grp_pi2=0;

replace probush_grp_pi0=pro_bush_grp if (campaign_interest==0);
replace progore_grp_pi0=pro_gore_grp if (campaign_interest==0);

replace probush_grp_pi1=pro_bush_grp if (campaign_interest==.5);
replace progore_grp_pi1=pro_gore_grp if (campaign_interest==.5);

replace probush_grp_pi2=pro_bush_grp if (campaign_interest==1);
replace progore_grp_pi2=pro_gore_grp if (campaign_interest==1);

tab campaign_interest, gen(ci_);
drop ci_1;

oprobit RBushGoreVoteChoice bgvc_*
probush_grp_pi* progore_grp_pi* totaladgrp ci_* ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse days 
event_* wd_* sd_*, cluster(media_zone);

outreg using logs\PanelTable5.out, nocons coefastr 3aster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;

* -> % correctly predicted;

predict o1 o2 o3 if e(sample);
gen outcomematch=0 if e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==-1 & max(o1,o2,o3)==o1 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==0 & max(o1,o2,o3)==o2 & e(sample);
replace outcomematch=1 if RBushGoreVoteChoice==1 & max(o1,o2,o3)==o3 & e(sample);
summ outcomematch if e(sample);
drop outcomematch o1 o2 o3;

* -> clarify results <- *;

quietly estsimp oprobit RBushGoreVoteChoice bgvc_*
probush_grp_pi* progore_grp_pi* totaladgrp ci_* ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse days 
event_* wd_1-wd_5 wd_7-wd_10 sd_*, robust genname(z_);

quietly setx 0;
quietly setx (totaladgrp days) mean;
quietly setx event_debate1 1 event_debate2 1 event_debate3 1; 
quietly setx ideology 0 pid5 0 attend_church 1 union 0 income 6 income_dkna 0 employed 1 education 7 hispanic 0 white 1 female 1 comphouse 0 age 46 age2 2116; 

simqi;

summ pro_bush_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+r(sd));
setx probush_grp_pi0 `from';
simqi;
simqi, fd(pr) changex(probush_grp_pi0 `from' `to');
setx probush_grp_pi0 0 probush_grp_pi1 `from';
setx ci_2 1;
simqi;
simqi, fd(pr) changex(probush_grp_pi1 `from' `to');
setx probush_grp_pi1 0 probush_grp_pi2 `from';
setx ci_2 0 ci_3 1;
simqi;
simqi, fd(pr) changex(probush_grp_pi2 `from' `to');
setx ci_3 0 probush_grp_pi2 0;

summ pro_gore_grp;
quietly local from=(r(mean));
quietly local to=(r(mean)+r(sd));
setx progore_grp_pi0 `from';
simqi;
simqi, fd(pr) changex(progore_grp_pi0 `from' `to');
setx progore_grp_pi0 0 progore_grp_pi1 `from';
setx ci_2 1;
simqi;
simqi, fd(pr) changex(progore_grp_pi1 `from' `to');
setx progore_grp_pi1 0 progore_grp_pi2 `from';
setx ci_2 0 ci_3 1;
simqi;
simqi, fd(pr) changex(progore_grp_pi2 `from' `to');
setx ci_3 0 progore_grp_pi2 0;

drop z_*;

log close;

***********************************************************************************************************
* Robustness of Vote Choice                                                                               *
***********************************************************************************************************;

log using logs\PanelRobustness_`suffix'.log, text replace;

*exclude demographics;
oprobit RBushGoreVoteChoice bgvc_*
pro_bush_grp pro_gore_grp totaladgrp comphouse 
days event_* wd_* sd_*, cluster(media_zone);

oprobit RBushGoreVoteChoice bgvc_*
pro_bush_grp pro_gore_grp totaladgrp employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_*, cluster(media_zone);

*exclude state dummies;
oprobit RBushGoreVoteChoice bgvc_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_*, cluster(media_zone);

*exclude week dummies;
oprobit RBushGoreVoteChoice bgvc_*
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
wd_*, cluster(media_zone);

*exclude each state;

encode state, gen(stnum);

oprobit BushGoreVoteChoice
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if stnum~=1, cluster(media_zone);
outreg using logs\PanelTable3DroppingStates.out, nocons noaster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes replace;

local ctr=2;
while `ctr'<=20 {;
oprobit BushGoreVoteChoice
pro_bush_grp pro_gore_grp totaladgrp ideology pid5 attend_church union income income_dkna employed education hispanic white female age age2 comphouse 
days event_* wd_* sd_* if stnum~=`ctr', cluster(media_zone);
outreg using logs\PanelTable3DroppingStates.out, nocons noaster se addstat(log-likelihood, e(ll)) bfmt(fc) bdec(3) tdec(2) ctitle(`e(depvar)') nonotes append;
local ctr=`ctr'+1;
};

log close;
